
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/inbound/mesProInOrder.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "入库单",
      name: "mesProInOrder",
      url: "/mesProInOrder/",
      sortName: "id",
    });
    const editFormFields = ref({
      orderType: "",
      inboundOrderNo: "",
      upperOrderNo: "",
      remark: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "单据类型",
          required: true,
          field: "orderType",
          type: "select",
          dataKey: "inOrderType",
          data: [],
        },
        {
          field: "inboundOrderNo",
          title: "单据编号",
          type: "string",
        },
        {
          title: "上游单据编号",
          field: "upperOrderNo",
          type: "string",
        },
        {
          title: "备注",
          field: "remark",
          type: "textarea",
        },
      ],
    ]);
    const searchFormFields = ref({
      inboundOrderNo: "",
      upperOrderNo: "",
      orderType: "",
      orderStatus: "",
      createType: "",
      creater: "",
      createDate: "",
    });
    const searchFormOptions = ref([
      [
        { title: "单据编号", field: "inboundOrderNo", type: "like" },
        { title: "上游单据编号", field: "upperOrderNo", type: "like" },
        {
          title: "单据类型",
          field: "orderType",
          type: "select",
          dataKey: "inOrderType",
          data: [],
        },
        {
          title: "单据状态",
          field: "orderStatus",
          type: "select",
          dataKey: "inboundState",
          data: [],
        },
      ],
      [
        {
          title: "创建方式",
          field: "createType",
          type: "select",
          dataKey: "createType",
          data: [],
        },
        { title: "创建者", field: "creater", type: "like" },
        { title: "创建时间", field: "createDate", type: "datetime" },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
            {
          field: "warehouseId",
          title: "仓库",
          type: "string",
          width: 90,
          align: "left",
          bind:{key: "warehouses", data: []}
      },
      {
        field: "proInOrderNo",
        title: "入库单据编号",
        type: "string",
        width: 120,
        align: "left",
        link: true,
      },
      {
        field: "batchNo",
        title: "胶框码",
        type: "string",
        width: 150,
        align: "left",
      },

      {
        field: "mesProStatus",
        title: "入库单状态",
        type: "string",
        width: 150,
        align: "left",
        // bind: { key: "inOrderType", data: [] },
      },
      {
        field: "unPackStock",
        title: "是否拆箱入库",
        type: "decimal",
        width: 90,
        align: "left",
      },
      {
        field: "workCenter",
        title: "工作中心",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "createType",
        title: "创建方式",
        type: "string",
        width: 120,
        align: "left",
        bind: { key: "createType", data: [] },
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "入库单明细",
      table: "mesProInOrderDetail",
      columns: [
        {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "orderId",
        title: "入库单主键",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "bagNo",
        title: "内包号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "productCode",
        title: "产品编码",
        type: "string",
        width: 150,
        align: "left",
      },
    {
        field: "overInQuantity",
        title: "上架数量",
        type: "string",
        width: 180,
        align: "left",
      },
      {
        field: "productVersion",
        title: "版本",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "setQty",
        title: "包装SET数量",
        type: "string",
        width: 120,
        align: "left",
      },
      {
        field: "okpcsqty",
        title: "合格PCS数",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "dateCode",
        title: "周期",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "xQty",
        title: "X数",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "xSite",
        title: "X位",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "weight",
        title: "内包重量",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "packingDate",
        title: "包装时间",
        type: "datetime",
        width: 200,
        align: "left",
      },
       {
        field: "lotNumber",
        title: "批次号",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "erpOrder",
        title: "ERP工单",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "moNumber",
        title: "制造订单",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "saleOrder",
        title: "销售订单",
        type: "string",
        width: 200,
        align: "left",
      }, {
        field: "remark",
        title: "备注",
        type: "string",
        width: 200,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
      ],
      sortName: "id",
      key: "id",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    